const svg = d3.select('svg');

const width = +svg.attr('width'),
      height = +svg.attr('height');

const render = data => {
  
  // d.mpg = +d.mpg;
  // d.cylinders = +d.cylinders;
  // d.displacement = +d.displacement;
  // d.horsepower = +d.horsepower;
  // d.weight = +d.weight;
  // d.acceleration = +d.acceleration;
  // d.year = +d.year;
  
  const chartTitle = 'Cars weight × horsepower',
  			xValue = d => d.weight,
        xAxisLabel = 'Weight',
        yValue = d => d.horsepower,
        yAxisLabel = 'Horsepower',
        circleRadius = 10,
        margin = {top: 60, right: 40, bottom: 60, left: 120},
        innerWidth = width - margin.left - margin.right,
        innerHeight = height - margin.top - margin.bottom;
  
  const xScale = d3.scaleLinear()
  	.domain(d3.extent(data, xValue))
  	.range([0, innerWidth])
  	.nice();
  
  const yScale = d3.scaleLinear()
  	.domain(d3.extent(data, yValue))
  	.range([0, innerHeight])
  	.nice();
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})`);
  
  const yAxis = d3.axisLeft(yScale)
  	.tickSize(-innerWidth)
  	.tickPadding(10);
  
  const yAxisG = g.append('g')
  	.attr('class', 'y-axis')
  	.call(yAxis);
  
  yAxisG.selectAll('.domain')
  		.remove();
  
  yAxisG.append('text')
  	.text(yAxisLabel)
  	.attr('fill', '#999')
  	.attr('x', -innerHeight/2)
  	.attr('y', -60)
  	.attr('transform', `rotate(-90)`)
  	.attr('text-anchor', 'middle')
  
  
  
  const xAxisTickFormat = number => 
  	d3.format('.2s')(number)
  	.replace('G', 'B')
  	.replace('.', ',');
  
  const xAxis = d3.axisBottom(xScale)
  	.tickFormat(xAxisTickFormat)
  	.tickSize(-innerHeight)
  	.tickPadding(10);
  
  const xAxisG = g.append('g')
  	.attr('class', 'x-axis')
  	.attr('transform', `translate(0, ${innerHeight})`)
  	.call(xAxis)
  	
	xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
  	.text(xAxisLabel)
  	.attr('fill', '#999')
  	.attr('x', innerWidth/2)
  	.attr('y', 50)
  
  
  g.selectAll('circle').data(data)
  	.enter().append('circle')
  		.attr('cy', d => yScale(yValue(d)))
  		.attr('cx', d => xScale(xValue(d)))
  		.attr('r', circleRadius)
  
  g.append('text')
  	.attr('class', 'h1')
  	.attr('y', -30)
  	.text(chartTitle)
  	.style('font-weight', 'bold')
  
};


d3.csv('data.csv')
  .then(data => {
    data.forEach(d => {
      d.mpg = +d.mpg;
      d.cylinders = +d.cylinders;
      d.displacement = +d.displacement;
      d.horsepower = +d.horsepower;
      d.weight = +d.weight;
      d.acceleration = +d.acceleration;
      d.year = +d.year;
    });
    render(data);
  });
